@@ -6,22 +6,13 @@ use base 'Catalyst::Engine::Apache2';
 
 use Apache2             ();
 use Apache::Connection  ();
-use Apache::Const       -compile => ':common';
+use Apache::Const       -compile => qw(OK);
 use Apache::RequestIO   ();
 use Apache::RequestRec  ();
 use Apache::RequestUtil ();
 use Apache::Response    ();
 
-sub status_constant {
-    return {
-        200 => Apache::Const::OK,
-        301 => Apache::Const::REDIRECT,
-        401 => Apache::Const::AUTH_REQUIRED,
-        403 => Apache::Const::FORBIDDEN,
-        404 => Apache::Const::NOT_FOUND,
-        500 => Apache::Const::SERVER_ERROR,
-    };
-}
+sub ok_constant { Apache::Const::OK }
 
 1;
 __END__
@@ -86,6 +77,10 @@ script/myapp_registry.pl (you will need to create this):
     use MyApp;
     
     MyApp->handle_request( Apache::RequestUtil->request );
+    
+=head1 METHODS
+
+=head2 ok_constant
 
 =head1 SEE ALSO
 
